.. complexity documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Nose-Watcher's documentation!
======================================

.. include:: ../README.rst
.. include:: ../CONTRIBUTING.rst
.. include:: ../AUTHORS.rst
.. include:: ../HISTORY.rst
